import json
import time
from seleniumwire import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.support import expected_conditions as ec
from webdriver_manager.chrome import ChromeDriverManager
from pprint import pprint as pp


def download(name, driver):
    with open(name, 'w') as file:
        json.dump(driver.har, file, indent=4)
        file.close()
    driver.quit()


def singleDownload(driver, download_type=1):
    wait = WebDriverWait(driver, 60)
    wait.until(ec.element_to_be_clickable((By.XPATH, '//*[@id="navbarNavDropdown"]/div/div[1]/div[2]/div')))
    driver.find_element(By.XPATH, '//*[@id="navbarNavDropdown"]/div/div[1]/div[2]/div').click()
    print('Clicking Export Price List')
    wait.until(ec.element_to_be_clickable((By.XPATH, '//*[@id="navbarNavDropdown"]/div/div[1]/div[2]/div/div/a[3]')))
    driver.find_element(By.XPATH, '//*[@id="navbarNavDropdown"]/div/div[1]/div[2]/div/div/a[3]').click()

    flower_xpath = '//html/body/ngb-modal-window/div/div/app-share-price-lists/div[2]/div/ul/li[2]/span'
    plants_xpath = '//html/body/ngb-modal-window/div/div/app-share-price-lists/div[2]/div/ul/li[3]/span'
    decoration_xpath = '//html/body/ngb-modal-window/div/div/app-share-price-lists/div[2]/div/ul/li[4]/span'
    ok_btn_xpath = '//html/body/ngb-modal-window/div/div/app-share-price-lists/div[3]/button[2]'

    if download_type == 1:
        print('Downloading Flower HAR')
        wait.until(ec.element_to_be_clickable((By.XPATH, flower_xpath)))
        driver.find_element(By.XPATH, flower_xpath).click()

    elif download_type == 2:
        print('Downloading Plants HAR')
        wait.until(ec.element_to_be_clickable((By.XPATH, plants_xpath)))
        driver.find_element(By.XPATH, plants_xpath).click()

    elif download_type == 3:
        print('Downloading Decorations HAR')
        wait.until(ec.element_to_be_clickable((By.XPATH, decoration_xpath)))
        driver.find_element(By.XPATH, decoration_xpath).click()

    driver.find_element(By.XPATH, ok_btn_xpath).click()
    print('Clicked OK...', end='')
    try:
        print('Waiting for download to finish.')
        progress = '//html/body/ngb-modal-window/div/div/app-share-price-lists/div[3]/button[2]/span[2]'
        wait.until(ec.presence_of_element_located((By.XPATH, progress)))
        try:
            time.sleep(1)
            while True:
                driver.find_element(By.CSS_SELECTOR, '.ladda-progress')
            # while driver.find_element(By.XPATH, progress).get_attribute('innerHTML') != '':
                print('waiting 5s..')
                time.sleep(5)
        except Exception as e:
            print('Downloaded!')
            if download_type == 1:
                download('flower.har', driver)
            elif download_type == 2:
                download('plants.har', driver)
            elif download_type == 3:
                download('decorations.har', driver)
    except Exception as e:
        print('err')


def driver_prep():
    options = webdriver.ChromeOptions()
    options.add_argument('--ignore-ssl-errors=yes')
    options.add_argument('--ignore-certificate-errors')
    options.add_argument('--headless')
    options.add_argument('--no-gpu')
    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/105.0.0.0 Safari/537.36',
    options.add_argument(f'--user-agent={user_agent}')
    prefs = {
        "download_restrictions": 3,
    }
    options.add_experimental_option(
        "prefs", prefs
    )
    enable_har = {
        'enable_har': True  # Capture HAR data, retrieve with driver.har
    }

    driver = webdriver.Chrome(ChromeDriverManager().install(), chrome_options=options, seleniumwire_options=enable_har)
    driver.scopes = [
        '.*/servoy-service/rest_ws/axws/rListRows/-1/false/2.*'
    ]
    driver.set_window_size(1366, 768)
    print('Logging in.')
    driver.get('https://www.floralwebshop.com/')

    wait = WebDriverWait(driver, 120)
    wait.until(ec.presence_of_element_located((By.ID, 'username')))
    wait.until(ec.presence_of_element_located((By.ID, 'password')))
    wait.until(ec.element_to_be_clickable((By.ID, 'login')))
    driver.find_element(By.ID, 'username').send_keys('010412')
    driver.find_element(By.ID, 'password').send_keys('Juzar1')
    driver.find_element(By.ID, 'login').click()

    wait.until(ec.element_to_be_clickable((By.ID, 'ok-btn')))
    driver.find_element(By.ID, 'ok-btn').click()
    print('Successfully Logged in.')

    loading_state_xpath = '//html/body/app-root/app-axe-layout/app-shop/div[1]/div[1]'
    wait.until(ec.presence_of_element_located((By.XPATH, loading_state_xpath)))
    print('Waiting for content to load!')
    while driver.find_element(By.XPATH, loading_state_xpath).text.strip() == 'Loading...':
        time.sleep(5)
    print('Content Loaded. Waiting 5s..')
    time.sleep(5)
    return driver


def main():
    singleDownload(driver_prep(), 2)
    singleDownload(driver_prep(), 3)
    singleDownload(driver_prep())


if __name__ == '__main__':
    main()
